@@ -40,8 +40,10 @@ class Categorise(CLIBase):
         for currentFile in currentDirectory.iterdir():
             if self._cat in currentFile.stem:
                 print(currentFile)
-                path = Path(self._cat, currentFile)
-                print(path)
+                target = pathlib.Path(self._cat, currentFile)
+                print(target)
+                currentFile = currentFile.replace(target)
+                print(currentFile)
 
 #if __name__ == '__main__':
 #    app = Inventory()
